@@ -94,6 +94,7 @@ class MonitorJobSiteSQL:
       self.tunnelDesignator = ""
 
       self.exitSystemCallOnInterrupt = False
+      self.terminateNoOp             = False
 
       signal.signal(signal.SIGINT,self.sigINT_handler)
       signal.signal(signal.SIGHUP,self.sigHUP_handler)
@@ -119,7 +120,7 @@ class MonitorJobSiteSQL:
                   record = commentPattern.sub("",record)
                   if   sectionPattern.match(record):
                      sectionName = sectionPattern.match(record).group(2)
-                     inMonitorSection = (sectionName == 'monitor')
+                     inMonitorSection = (sectionName == 'site')
                      if inMonitorSection:
                         self.configData = {'mysqlHost':"",
                                            'mysqlUser':"",
@@ -192,12 +193,14 @@ class MonitorJobSiteSQL:
 
 
    def terminate(self):
-      if self.siteMonitorPid:
+      if   self.siteMonitorPid:
          self.logger.log(logging.INFO,getLogMessage("Send TERM to child ssh process"))
          try:
             os.kill(self.siteMonitorPid,signal.SIGTERM)
          except:
             pass
+      elif not self.sshCommand:
+         self.terminateNoOp = True
 
 
    def sigGEN_handler(self,
@@ -888,7 +891,8 @@ class MonitorJobSiteSQL:
                self.logger.log(logging.ERROR,getLogMessage("Activated job site %s not pending" % (self.siteDesignator)))
 
             now = time.time()
-            while time.time()-now < self.noOpInactivityInterval:
+         
+            while (not self.terminateNoOp) and (time.time()-now < self.noOpInactivityInterval):
                newRemoteJobIds = self.getNewRemoteJobIds()
                if len(newRemoteJobIds) > 0:
                   now = time.time()
